//
//      Binary Responses for NStg Latent Classes 
//      Y. Okamoto, 2018.11, 2019.03
//
data {
    int N;                //  Number of subjects
    int M;                //  Number of items
    int NStg;             //  Number of stages
    int X[N, M];          //  Responses:  1 -> failure, 2 -> success
    vector[NStg + 1] a;   //  Parameters for Dirichlet distributions
}
parameters {
    simplex[NStg+1] p_step[M];
    simplex[NStg]   theta[N];
}
transformed parameters {
    real p[M, NStg];
    real p_person[N, M];
    vector[2] p_person_cat[N, M];
 
    for (i in 1:M) {
        for (stg in 1:NStg) {
                p[i][stg] = 0.0;
                for (s in 1:stg){
                    p[i][stg] += p_step[i][s];
                }
            }
    }
    
    for (j in 1:N) {
        for (i in 1:M){
            p_person[j][i] = 0.0;
            for (stg in 1:NStg){
                p_person[j][i] = p_person[j][i] + p[i][stg] * theta[j][stg]; 
            }
        }
    }
    for (j in 1:N) {
        for (i in 1:M) {
            p_person_cat[j][i][2] = p_person[j][i];
            p_person_cat[j][i][1] = 1.0 - p_person_cat[j][i][2];
        }
    }
}
model {
    for (i in 1:M){
        p_step[i] ~ dirichlet(a);
    }
    for (j in 1:N) {
        for (i in 1:M){
            X[j][i] ~ categorical(p_person_cat[j][i]);
        }
    }
}

